@@ -24,6 +24,8 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-alb-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.alblambda`|
 
+## Overview
+
 This AWS Solutions Construct implements an an Application Load Balancer to an AWS Lambda function
 
 Here is a minimal deployable pattern definition:
@@ -189,7 +191,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -201,6 +203,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -221,17 +225,17 @@ class AlbToLambda(
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         listener_props: typing.Any = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
-        rule_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps] = None,
-        target_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+        target_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -249,6 +253,10 @@ class AlbToLambda(
         :param target_props: Optional custom properties for a new target group. While this is a standard attribute of props for ALB constructs, there are few pertinent properties for a Lambda target. Default: - none
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. Default: - none
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AlbToLambdaProps(
             public_api=public_api,
             alb_logging_bucket_props=alb_logging_bucket_props,
@@ -312,17 +320,17 @@ class AlbToLambdaProps:
         self,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         listener_props: typing.Any = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
-        rule_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps] = None,
-        target_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+        target_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC and ALB. Default: - none
@@ -348,6 +356,20 @@ class AlbToLambdaProps:
             target_props = aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps(**target_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbToLambdaProps.__init__)
+            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
+            check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_load_balancer_obj", value=existing_load_balancer_obj, expected_type=type_hints["existing_load_balancer_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument listener_props", value=listener_props, expected_type=type_hints["listener_props"])
+            check_type(argname="argument load_balancer_props", value=load_balancer_props, expected_type=type_hints["load_balancer_props"])
+            check_type(argname="argument log_alb_access_logs", value=log_alb_access_logs, expected_type=type_hints["log_alb_access_logs"])
+            check_type(argname="argument rule_props", value=rule_props, expected_type=type_hints["rule_props"])
+            check_type(argname="argument target_props", value=target_props, expected_type=type_hints["target_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
